==> haskell-conduit-extra-1.3.6-122-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 conduit-extra
version:              1.3.6
visibility:           public
id:                   conduit-extra-1.3.6-4mz83EqxbHCEzuTWI9bnK7
key:                  conduit-extra-1.3.6-4mz83EqxbHCEzuTWI9bnK7
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.

category:             Data, Conduit
abi:                  098c85ed9529cb1a0313877b237b4f09
exposed:              True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib

import-dirs:          /usr/lib/ghc-9.2.8/site-local/conduit-extra-1.3.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/conduit-extra-1.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-extra
hs-libraries:         HSconduit-extra-1.3.6-4mz83EqxbHCEzuTWI9bnK7
depends:
    async-2.2.5-6x2K3uKDvG1IztgfKbhaBt
    attoparsec-0.14.4-Hiemanhccqu1mV1syxTVmO base-4.16.4.0
    bytestring-0.11.4.0 conduit-1.3.5-AGmcSDEpJ3n4ZMXbZtc7Qq
    directory-1.3.6.2 filepath-1.4.2.2
    network-3.1.4.0-BiKXa6Hb7TTJJZ5dknebZ6
    primitive-0.7.4.0-B3DrOLQXe0rK3L3yTztXl process-1.6.16.0
    resourcet-1.2.6-8C7hdAXlJmHCafpDJiwdp stm-2.5.0.2
    streaming-commons-0.2.2.6-6VbBFEjkhNm24yOl47GQE9 text-1.2.5.0
    transformers-0.5.6.2 typed-process-0.2.11.1-AiYJZU1voNI38M3X1V7Ctf
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:
    /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock

haddock-html:         /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-extra-1.3.6-123-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 conduit-extra
version:              1.3.6
visibility:           public
id:                   conduit-extra-1.3.6-JlXl8kPZW3JH7iDYxYzmJw
key:                  conduit-extra-1.3.6-JlXl8kPZW3JH7iDYxYzmJw
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.

category:             Data, Conduit
abi:                  c38fd4e136a315659f4588d3a690e78a
exposed:              True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib

import-dirs:          /usr/lib/ghc-9.2.8/site-local/conduit-extra-1.3.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/conduit-extra-1.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-extra
hs-libraries:         HSconduit-extra-1.3.6-JlXl8kPZW3JH7iDYxYzmJw
depends:
    async-2.2.5-E2Nvh3WkFMk4pawohHisBC
    attoparsec-0.14.4-6bGZjP6ZyLf9ECb8I9ykxo base-4.16.4.0
    bytestring-0.11.4.0 conduit-1.3.5-7uOaL8TmoCPJlIbHrkXLwR
    directory-1.3.6.2 filepath-1.4.2.2
    network-3.1.4.0-GnkgUFaZcoiLS7LTArWHTl
    primitive-0.7.4.0-7EmETL08CQ5nNVujSkVxd process-1.6.16.0
    resourcet-1.2.6-Eh9ERdfgEXDnlhBOVqt0T stm-2.5.0.2
    streaming-commons-0.2.2.6-GtKiLSicjpNAq5IU8Xg7sf text-1.2.5.0
    transformers-0.5.6.2 typed-process-0.2.11.1-9TtBQebp14QFH0pYlvneTG
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:
    /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock

haddock-html:         /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
